@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2024 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -25,7 +25,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-extern void includeGpmScreen (MainScreen *);
+extern void gpmIncludeScreenHandlers (MainScreen *);
 
 #ifdef __cplusplus
 }
