@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2020 by The BRLTTY Developers.
+ * Copyright (C) 1995-2024 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -25,8 +25,8 @@
 extern "C" {
 #endif /* __cplusplus */
 
-extern int tellSpeechFinished (volatile SpeechSynthesizer *spk);
-extern int tellSpeechLocation (volatile SpeechSynthesizer *spk, int index);
+extern int tellSpeechFinished (SpeechSynthesizer *spk);
+extern int tellSpeechLocation (SpeechSynthesizer *spk, int index);
 
 extern unsigned int getIntegerSpeechVolume (unsigned char setting, unsigned int normal);
 extern unsigned int getIntegerSpeechRate (unsigned char setting, unsigned int normal);
